# frozen_string_literal: true

module Osso
  module Error
    class OAuthError < Base
      def docs_url
        'https://ossoapp.com/docs/integration/oauth-consumption'
      end
    end

    class NoAccountForOAuthClientError < OAuthError
      def initialize(domain: 'the requested domain')
        super
        @domain = domain
      end

      def message
        "No customer account exists for #{@domain} and OAuth client pair. " \
          "Review our OAuth documentation, and check you're using the correct OAuth client identifier. " \
          'This usually suggests an engineering issue with your ENV variables.'
      end
    end

    class InvalidOAuthClientIdentifier < OAuthError
      def message
        'No OAuth client exists for the requested OAuth client identifier. ' \
          "Review our OAuth documentation, and ensure you're using a valid OAuth client identifier. " \
          'OAuth credentials may have been regenerated by your team.'
      end
    end

    class InvalidRedirectUri < OAuthError
      def initialize(redirect_uri:)
        super
        @redirect_uri = redirect_uri
      end

      def message
        "The requested redirect URI #{@redirect_uri} is not on the allow-list for the rquested " \
        'OAuth client identifier. Review our OAuth documentation, check you\'re using the correct ' \
        'OAuth client identifier, and confirm your Redirect URI allow-list includes the ' \
        'appropriate URI(s).'
      end
    end
  end
end
